CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
22 lines
597 B
Common Lisp
22 lines
597 B
Common Lisp
|
|
#pragma OPENCL EXTENSION cl_khr_fp16 : enable
|
|
|
|
// GCN: {{^}}test_asin_f16:
|
|
// GFX700: v_cvt_f32_f16{{(_e32)?}} [[CVT:v[0-9]+]]
|
|
// GFX700: v_cmp_le_f32{{(_e64)?}} s{{\[[0-9]+:[0-9]+\]}}, |[[CVT]]|, 0.5
|
|
// GFX700: v_mul_f32
|
|
// GFX700: v_mad_f32
|
|
// GFX700: v_sqrt_f32
|
|
// GFX700: v_bfi_b32
|
|
// GFX700: v_cvt_f16_f32
|
|
|
|
|
|
// GFX803: v_cmp_le_f16{{(_e64)?}} s{{\[[0-9]+:[0-9]+\]}}, |{{v[0-9]+}}|, 0.5
|
|
// GFX803: v_mad_f32
|
|
// GFX803: v_sqrt_f32
|
|
// GFX803: v_bfi_b32
|
|
kernel void test_asin_f16(global half* restrict out, global half* restrict in) {
|
|
int id = get_local_id(0);
|
|
out[id] = asin(in[id]);
|
|
}
|